@@ -22,16 +22,20 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
         this._getParentFormData = getParentFormData;
         var ids = [];
         var labels = [];
+        var types   = {};
         var trans = qx.locale.Manager;
-        cfg.table.forEach(function(row){
-            ids.push(row.key);
-            labels.push(trans['tr'](row.label));
-        })
+        cfg.table.forEach(function(col){
+            ids.push(col.key);
+            labels.push(trans['tr'](col.label));
+            types[col.key]   = col.type;
+        });
         this.setColumns(labels,ids);
-        cfg.table.forEach(function(row,i){
-            this.setColumnSortable(i,row.sortable ? true : false)
-        },this) 
+        cfg.table.forEach(function(col,i){
+            this.setColumnSortable(i,col.sortable ? true : false);
+        },this);
         this.__instanceName = cfg.name;
+        this.__types   = types;
+        this.__ids     = ids;
     },
 
     properties: {
@@ -43,6 +47,8 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
     members : {
         _getParentFormData: null,
         __instanceName : null,
+        __types : null,
+
         /**
          * Provid our implementation to make remote table work
          */
@@ -54,7 +60,7 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
             };
 
             if (this._getParentFormData){
-                rpcArgs.parentFormData = this._getParentFormData()
+                rpcArgs.parentFormData = this._getParentFormData();
             }
 
             rpc.callAsyncSmart(function(ret) {
@@ -87,14 +93,21 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
             }
 
             if (this._getParentFormData){
-                rpcArgs.parentFormData = this._getParentFormData()
+                rpcArgs.parentFormData = this._getParentFormData();
             }
 
             var rpc = callbackery.data.Server.getInstance();
             var that = this;
 
-            rpc.callAsyncSmart(function(ret) {
-                that._onRowDataLoaded(ret);
+            rpc.callAsyncSmart(function(data) {
+                data.forEach(function(col){
+                    for (var id in col) {
+                        if (that.__types[id] == 'date') {
+                            col[id] = new Date(col[id]);
+                        }
+                    }
+                }); 
+                that._onRowDataLoaded(data);
             },
             'getPluginData', this.__instanceName,'tableData',rpcArgs);
         }
