@@ -38,7 +38,7 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
                     this._add(new qx.ui.basic.Label(headerOptions.note).set({
                         rich: true,
                         alignX: 'left'
-                    }),{ row: this._row, column: 0, colSpan: 3})
+                    }),{ row: this._row, column: 0, colSpan: 3});
                     this._row++;
                 }
             }
