@@ -252,8 +252,8 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     );
                     return;
                 }
-                if (response.action){
-                    this.fireDataEvent('actionResponse',response.action || {});
+                if (response){
+                    this.fireDataEvent('actionResponse',response || {});
                 }
             },this);
 
