@@ -70,11 +70,13 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                 cfg.form,null,callbackery.ui.form.renderer.NoteForm).set({
                 paddingRight: 10
             });
-            form.addListener('changeData',function(){
-                if (this._loading == 0){ // only notify when update comes from human interaction
-                    this.fireDataEvent('actionResponse',{action: 'dataModified'});
-                }
-            },this);
+            if (cfg['options'] && cfg.options['warnAboutUnsavedData']){
+                form.addListener('changeData',function(){
+                    if (this._loading == 0){ // only notify when update comes from human interaction
+                        this.fireDataEvent('actionResponse',{action: 'dataModified'});
+                    }
+                },this);
+            }
             this.add(new qx.ui.container.Scroll(form),{flex: 1});
             var that = this;
             var action = this._action = new callbackery.ui.plugin.Action(
