@@ -79,21 +79,48 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                 }
             });
             var selectionModel = table.getSelectionModel();
+            var currentRow = null;
             selectionModel.setSelectionMode(qx.ui.table.selection.Model.SINGLE_SELECTION);
             selectionModel.addListener('changeSelection',function(){
                 selectionModel.iterateSelection(function(index) {
                     if (model.getRowData(index) != null) {
                         this.setSelection(model.getRowData(index));
+                        currentRow = index;
                     }
                 },this);
             },this);
-            var that = this;
             model.addListener('dataChanged',function(e){
-                // it seems that dataChanged is thrown as the model data
-                // is a bit early
-                // deferre the action until the thread is done
+                var lastData = this.getSelection();
                 new qx.util.DeferredCall(function(){
-                    selectionModel.resetSelection();
+                    if (currentRow !== null && qx.lang.Type.isObject(lastData) ){
+                        for (var offset=-1;offset<=1;offset++){
+                            if (currentRow + offset < 0){
+                                continue;
+                            }
+                            var currentData = model.getRowData(currentRow+offset);
+                            var gotPrimary = false;
+                            var equal = true;
+                            cfg.table.forEach(function(col,i){
+                                if (col.primary){
+                                    gotPrimary = true;
+                                    if (currentData[col.key] != lastData[col.key]){
+                                        equal = false;
+                                    }
+                                }
+                            });
+                            if (gotPrimary && equal){
+                                if (offset != 0){
+                                    table.clearFocusedRowHighlight();
+                                    table.setFocusedCell(0,currentRow+offset,false);
+                                    selectionModel.setSelectionInterval(currentRow+offset,currentRow+offset);
+                                }
+                                this.setSelection(currentData);
+                                return;
+                            }
+                        }
+                    }
+                    table.resetSelection();
+                    table.clearFocusedRowHighlight();
                     this.setSelection({});
                 },this).schedule();
             },this);
